@@ -268,7 +268,7 @@ static bool _cjose_jws_build_dig_hmac_sha(cjose_jws_t *jws, const cjose_jwk_t *j
     }
 
 // instantiate and initialize a new mac digest context
-#if (CJOSE_OPENSSL_11X)
+#if defined(CJOSE_OPENSSL_11X)
     ctx = HMAC_CTX_new();
 #else
     ctx = cjose_get_alloc()(sizeof(HMAC_CTX));
@@ -279,7 +279,7 @@ static bool _cjose_jws_build_dig_hmac_sha(cjose_jws_t *jws, const cjose_jwk_t *j
         goto _cjose_jws_build_dig_hmac_sha_cleanup;
     }
 
-#if !(CJOSE_OPENSSL_11X)
+#if !defined(CJOSE_OPENSSL_11X)
     HMAC_CTX_init(ctx);
 #endif
 
@@ -316,7 +316,7 @@ static bool _cjose_jws_build_dig_hmac_sha(cjose_jws_t *jws, const cjose_jwk_t *j
 _cjose_jws_build_dig_hmac_sha_cleanup:
     if (NULL != ctx)
     {
-#if (CJOSE_OPENSSL_11X)
+#if defined(CJOSE_OPENSSL_11X)
         HMAC_CTX_free(ctx);
 #else
         HMAC_CTX_cleanup(ctx);
@@ -565,7 +565,7 @@ static bool _cjose_jws_build_sig_ec(cjose_jws_t *jws, const cjose_jwk_t *jwk, cj
     memset(jws->sig, 0, jws->sig_len);
 
     const BIGNUM *pr, *ps;
-#if (CJOSE_OPENSSL_11X)
+#if defined(CJOSE_OPENSSL_11X)
     ECDSA_SIG_get0(ecdsa_sig, &pr, &ps);
 #else
     pr = ecdsa_sig->r;
@@ -1007,7 +1007,7 @@ static bool _cjose_jws_verify_sig_ec(cjose_jws_t *jws, const cjose_jwk_t *jwk, c
     ECDSA_SIG *ecdsa_sig = ECDSA_SIG_new();
     int key_len = jws->sig_len / 2;
 
-#if (CJOSE_OPENSSL_11X)
+#if defined(CJOSE_OPENSSL_11X)
     BIGNUM *pr = BN_new(), *ps = BN_new();
     BN_bin2bn(jws->sig, key_len, pr);
     BN_bin2bn(jws->sig + key_len, key_len, ps);
